==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/QuartzSetup/src/com/clustercontrol/MonitorSetup.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol;

import java.util.Hashtable;

import javax.naming.InitialContext;
import javax.naming.NamingException;

import com.clustercontrol.monitor.ejb.session.MonitorController;
import com.clustercontrol.monitor.ejb.session.MonitorControllerHome;

/**
 * ִƻQuartzꥯ饹
 *
 * @version 2.0.0
 * @since 1.0.0
 */
public class MonitorSetup {
    public static final String QUARTZ_NAME = "Quartz";
    
    /**
     * ᥤ
     * 
     * @param args
     */
    public static void main(String[] args) {
        MonitorSetup setup = new MonitorSetup();
        try {
            setup.setup(args);
        } catch (Exception e) {
        	e.printStackTrace();
        }
    }

    /**
     * QuartzϿ
     * @param args
     */
    public void setup(String[] args) throws Exception {
        if(args.length != 2 && args.length != 3){
            return;
        }
        
        //QuartzScheduleråå
        InitialContext context = getContext("jnp://" + args[1]);
        MonitorControllerHome home = 
            (MonitorControllerHome)context.lookup(MonitorControllerHome.JNDI_NAME);
        
        MonitorController monitorController = home.create();
        
        if(args[0].compareTo("add") == 0){
        	monitorController.addQuartz(args[2]);
        }
        else if(args[0].compareTo("del") == 0){
        	monitorController.deleteQuartz();
        }
    }
    
    /**
     * InitialContext
     * 
     * @return
     * @throws NamingException
     */
    private InitialContext getContext(String url) throws NamingException {
        Hashtable props = new Hashtable();
        
        props.put(InitialContext.INITIAL_CONTEXT_FACTORY, 
                "org.jnp.interfaces.NamingContextFactory");
        props.put(InitialContext.PROVIDER_URL, 
                url);

        InitialContext initialContext = new InitialContext(props);
        return initialContext;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/QuartzSetup/src/com/clustercontrol/MonitorSetup.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol;

import java.util.Hashtable;

import javax.naming.InitialContext;
import javax.naming.NamingException;

import com.clustercontrol.monitor.ejb.session.MonitorController;
import com.clustercontrol.monitor.ejb.session.MonitorControllerHome;

/**
 * 状態監視用Quartz設定クラス
 *
 * @version 2.0.0
 * @since 1.0.0
 */
public class MonitorSetup {
    public static final String QUARTZ_NAME = "Quartz";
    
    /**
     * メイン
     * 
     * @param args
     */
    public static void main(String[] args) {
        MonitorSetup setup = new MonitorSetup();
        try {
            setup.setup(args);
        } catch (Exception e) {
        	e.printStackTrace();
        }
    }

    /**
     * Quartzへ登録
     * @param args
     */
    public void setup(String[] args) throws Exception {
        if(args.length != 2 && args.length != 3){
            return;
        }
        
        //QuartzのSchedulerをルックアップ
        InitialContext context = getContext("jnp://" + args[1]);
        MonitorControllerHome home = 
            (MonitorControllerHome)context.lookup(MonitorControllerHome.JNDI_NAME);
        
        MonitorController monitorController = home.create();
        
        if(args[0].compareTo("add") == 0){
        	monitorController.addQuartz(args[2]);
        }
        else if(args[0].compareTo("del") == 0){
        	monitorController.deleteQuartz();
        }
    }
    
    /**
     * InitialContext作成
     * 
     * @return
     * @throws NamingException
     */
    private InitialContext getContext(String url) throws NamingException {
        Hashtable props = new Hashtable();
        
        props.put(InitialContext.INITIAL_CONTEXT_FACTORY, 
                "org.jnp.interfaces.NamingContextFactory");
        props.put(InitialContext.PROVIDER_URL, 
                url);

        InitialContext initialContext = new InitialContext(props);
        return initialContext;
    }
}
